package com.muyu.service.serviceImpl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.domain.constants.EngineVersion;
import com.muyu.domain.constants.ConfigCodeConstants;
import com.muyu.mapper.EngineVersionMapper;
import com.muyu.resp.EngineConfigScopeResp;
import com.muyu.service.EngineVersionService;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;

/**
 * @Author：qdm
 * @Package：com.muyu.service.serviceImpl
 * @Project：cloud-etl-engine
 * @name：EngineVersionServiceImpl
 * @Date：2024/8/22 22:17
 */
@Service
public class EngineVersionServiceImpl extends ServiceImpl<EngineVersionMapper, EngineVersion> implements EngineVersionService {


    @Override
    public List<EngineVersion> list(EngineVersion engineConfig) {
        LambdaQueryWrapper<EngineVersion> queryWrapper = new LambdaQueryWrapper<>();

        if (StringUtils.isNotNull(engineConfig.getVersionCode())) {
            queryWrapper.eq(EngineVersion::getVersionCode, engineConfig.getVersionCode());
        }

        if (StringUtils.isNotNull(engineConfig.getRuleContent())) {
            queryWrapper.eq(EngineVersion::getRuleContent, engineConfig.getRuleContent());
        }

        if (StringUtils.isNotNull(engineConfig.getEngineMaintenanceId())) {
            queryWrapper.eq(EngineVersion::getEngineMaintenanceId, engineConfig.getEngineMaintenanceId());
        }

        return list(queryWrapper);
    }

    @Override
    public EngineVersion add(EngineVersion engineVersion) {
        if (save(engineVersion)) {
            return engineVersion;
        }
        return null;
    }

    @Override
    public EngineVersion updateMsg(EngineVersion engineVersion) {
        boolean b = updateById(engineVersion);
        if (b) {
            return null;
        }
        return null;
    }

    @Override
    public Result<EngineVersion> updateVersion(EngineVersion engineVersion) {
        return null;
    }

    @Override
    public List<EngineConfigScopeResp> getScopeList() {
        List<EngineConfigScopeResp> list = new ArrayList<>();
        try {
            int i = 0;
            for (String scope : ConfigCodeConstants.CONFIG_FILE_NAME_ARRAY) {
                if (i == 0) {
                    i++;
                    continue;
                }
                String path = ConfigCodeConstants.BASE_FILE_PATH + scope;
                String code = Files.readString(Paths.get(path));
                String type = ConfigCodeConstants.CONFIG_FILE_TYPE_ARRAY[i++];
                list.add(EngineConfigScopeResp.builder()
                        .type(type)
                        .name(scope)
                        .code(code)
                        .build());
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        return list;
    }

    @Override
    public EngineConfigScopeResp getScopeInfoById(Integer id) {
        String scope = ConfigCodeConstants.CONFIG_FILE_NAME_ARRAY[id];
        String type = ConfigCodeConstants.CONFIG_FILE_TYPE_ARRAY[id];
        String path = ConfigCodeConstants.BASE_FILE_PATH + scope;
        String code = null;
        try {
            code = Files.readString(Paths.get(path));
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        return EngineConfigScopeResp.builder()
                .type(type)
                .name(scope)
                .code(code)
                .build();
    }
}
